# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from oci._vendor import requests  # noqa: F401
from oci._vendor import six

from oci import retry, circuit_breaker  # noqa: F401
from oci.base_client import BaseClient
from oci.config import get_config_value_or_default, validate_config
from oci.signer import Signer
from oci.util import Sentinel, get_signer_from_authentication_type, AUTHENTICATION_TYPE_FIELD_NAME
from .models import announcements_service_type_mapping
missing = Sentinel("Missing")


class AnnouncementSubscriptionClient(object):
    """
    Manage Oracle Cloud Infrastructure console announcements.
    """

    def __init__(self, config, **kwargs):
        """
        Creates a new service client

        :param dict config:
            Configuration keys and values as per `SDK and Tool Configuration <https://docs.cloud.oracle.com/Content/API/Concepts/sdkconfig.htm>`__.
            The :py:meth:`~oci.config.from_file` method can be used to load configuration from a file. Alternatively, a ``dict`` can be passed. You can validate_config
            the dict using :py:meth:`~oci.config.validate_config`

        :param str service_endpoint: (optional)
            The endpoint of the service to call using this client. For example ``https://iaas.us-ashburn-1.oraclecloud.com``. If this keyword argument is
            not provided then it will be derived using the region in the config parameter. You should only provide this keyword argument if you have an explicit
            need to specify a service endpoint.

        :param timeout: (optional)
            The connection and read timeouts for the client. The default values are connection timeout 10 seconds and read timeout 60 seconds. This keyword argument can be provided
            as a single float, in which case the value provided is used for both the read and connection timeouts, or as a tuple of two floats. If
            a tuple is provided then the first value is used as the connection timeout and the second value as the read timeout.
        :type timeout: float or tuple(float, float)

        :param signer: (optional)
            The signer to use when signing requests made by the service client. The default is to use a :py:class:`~oci.signer.Signer` based on the values
            provided in the config parameter.

            One use case for this parameter is for `Instance Principals authentication <https://docs.cloud.oracle.com/Content/Identity/Tasks/callingservicesfrominstances.htm>`__
            by passing an instance of :py:class:`~oci.auth.signers.InstancePrincipalsSecurityTokenSigner` as the value for this keyword argument
        :type signer: :py:class:`~oci.signer.AbstractBaseSigner`

        :param obj retry_strategy: (optional)
            A retry strategy to apply to all calls made by this service client (i.e. at the client level). There is no retry strategy applied by default.
            Retry strategies can also be applied at the operation level by passing a ``retry_strategy`` keyword argument as part of calling the operation.
            Any value provided at the operation level will override whatever is specified at the client level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. A convenience :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY`
            is also available. The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

        :param obj circuit_breaker_strategy: (optional)
            A circuit breaker strategy to apply to all calls made by this service client (i.e. at the client level).
            This client uses :py:data:`~oci.circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY` as default if no circuit breaker strategy is provided.
            The specifics of circuit breaker strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/circuit_breakers.html>`__.

        :param function circuit_breaker_callback: (optional)
            Callback function to receive any exceptions triggerred by the circuit breaker.

        :param allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this client should allow control characters in the response object. By default, the client will not
            allow control characters to be in the response object.
        """
        validate_config(config, signer=kwargs.get('signer'))
        if 'signer' in kwargs:
            signer = kwargs['signer']

        elif AUTHENTICATION_TYPE_FIELD_NAME in config:
            signer = get_signer_from_authentication_type(config)

        else:
            signer = Signer(
                tenancy=config["tenancy"],
                user=config["user"],
                fingerprint=config["fingerprint"],
                private_key_file_location=config.get("key_file"),
                pass_phrase=get_config_value_or_default(config, "pass_phrase"),
                private_key_content=config.get("key_content")
            )

        base_client_init_kwargs = {
            'regional_client': True,
            'service_endpoint': kwargs.get('service_endpoint'),
            'base_path': '/20180904',
            'service_endpoint_template': 'https://announcements.{region}.oci.{secondLevelDomain}',
            'skip_deserialization': kwargs.get('skip_deserialization', False),
            'circuit_breaker_strategy': kwargs.get('circuit_breaker_strategy', circuit_breaker.GLOBAL_CIRCUIT_BREAKER_STRATEGY)
        }
        if 'timeout' in kwargs:
            base_client_init_kwargs['timeout'] = kwargs.get('timeout')
        if base_client_init_kwargs.get('circuit_breaker_strategy') is None:
            base_client_init_kwargs['circuit_breaker_strategy'] = circuit_breaker.DEFAULT_CIRCUIT_BREAKER_STRATEGY
        if 'allow_control_chars' in kwargs:
            base_client_init_kwargs['allow_control_chars'] = kwargs.get('allow_control_chars')
        self.base_client = BaseClient("announcement_subscription", config, signer, announcements_service_type_mapping, **base_client_init_kwargs)
        self.retry_strategy = kwargs.get('retry_strategy')
        self.circuit_breaker_callback = kwargs.get('circuit_breaker_callback')

    def change_announcement_subscription_compartment(self, announcement_subscription_id, change_announcement_subscription_compartment_details, **kwargs):
        """
        Moves the specified announcement subscription from one compartment to another compartment. When provided, If-Match is checked against ETag values of the resource.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str announcement_subscription_id: (required)
            The OCID of the announcement subscription.

        :param oci.announcements_service.models.ChangeAnnouncementSubscriptionCompartmentDetails change_announcement_subscription_compartment_details: (required)
            The compartment information to update.

        :param str if_match: (optional)
            The locking version, used for optimistic concurrency control.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/change_announcement_subscription_compartment.py.html>`__ to see an example of how to use change_announcement_subscription_compartment API.
        """
        resource_path = "/announcementSubscriptions/{announcementSubscriptionId}/actions/changeCompartment"
        method = "POST"
        operation_name = "change_announcement_subscription_compartment"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/ChangeAnnouncementSubscriptionCompartment"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "change_announcement_subscription_compartment got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementSubscriptionId": announcement_subscription_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_announcement_subscription_compartment_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=change_announcement_subscription_compartment_details,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def create_announcement_subscription(self, create_announcement_subscription_details, **kwargs):
        """
        Creates a new announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param oci.announcements_service.models.CreateAnnouncementSubscriptionDetails create_announcement_subscription_details: (required)
            Details of the new announcement subscription.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.AnnouncementSubscription`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/create_announcement_subscription.py.html>`__ to see an example of how to use create_announcement_subscription API.
        """
        resource_path = "/announcementSubscriptions"
        method = "POST"
        operation_name = "create_announcement_subscription"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/CreateAnnouncementSubscription"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_announcement_subscription got unknown kwargs: {!r}".format(extra_kwargs))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_announcement_subscription_details,
                response_type="AnnouncementSubscription",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                header_params=header_params,
                body=create_announcement_subscription_details,
                response_type="AnnouncementSubscription",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def create_filter_group(self, announcement_subscription_id, create_filter_group_details, **kwargs):
        """
        Creates a new filter group in the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str announcement_subscription_id: (required)
            The OCID of the announcement subscription.

        :param oci.announcements_service.models.CreateFilterGroupDetails create_filter_group_details: (required)
            Details of the new filter group.

        :param str opc_retry_token: (optional)
            A token that uniquely identifies a request so it can be retried in case of a timeout or
            server error without risk of executing that same action again. Retry tokens expire after 24
            hours, but can be invalidated before then due to conflicting operations. For example, if a resource
            has been deleted and purged from the system, then a retry of the original creation request
            might be rejected.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param str if_match: (optional)
            The locking version, used for optimistic concurrency control.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.FilterGroup`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/create_filter_group.py.html>`__ to see an example of how to use create_filter_group API.
        """
        resource_path = "/announcementSubscriptions/{announcementSubscriptionId}/filterGroups"
        method = "POST"
        operation_name = "create_filter_group"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/CreateFilterGroup"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_retry_token",
            "opc_request_id",
            "if_match"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "create_filter_group got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementSubscriptionId": announcement_subscription_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-retry-token": kwargs.get("opc_retry_token", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing),
            "if-match": kwargs.get("if_match", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_retry_token_if_needed(header_params)
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=create_filter_group_details,
                response_type="FilterGroup",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=create_filter_group_details,
                response_type="FilterGroup",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def delete_announcement_subscription(self, announcement_subscription_id, **kwargs):
        """
        Deletes the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str announcement_subscription_id: (required)
            The OCID of the announcement subscription.

        :param str if_match: (optional)
            The locking version, used for optimistic concurrency control.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/delete_announcement_subscription.py.html>`__ to see an example of how to use delete_announcement_subscription API.
        """
        resource_path = "/announcementSubscriptions/{announcementSubscriptionId}"
        method = "DELETE"
        operation_name = "delete_announcement_subscription"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/DeleteAnnouncementSubscription"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_announcement_subscription got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementSubscriptionId": announcement_subscription_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def delete_filter_group(self, announcement_subscription_id, filter_group_name, **kwargs):
        """
        Deletes a filter group in the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str announcement_subscription_id: (required)
            The OCID of the announcement subscription.

        :param str filter_group_name: (required)
            The name of the filter group.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param str if_match: (optional)
            The locking version, used for optimistic concurrency control.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type None
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/delete_filter_group.py.html>`__ to see an example of how to use delete_filter_group API.
        """
        resource_path = "/announcementSubscriptions/{announcementSubscriptionId}/filterGroups/{filterGroupName}"
        method = "DELETE"
        operation_name = "delete_filter_group"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/DeleteFilterGroup"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_request_id",
            "if_match"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "delete_filter_group got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementSubscriptionId": announcement_subscription_id,
            "filterGroupName": filter_group_name
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing),
            "if-match": kwargs.get("if_match", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def get_announcement_subscription(self, announcement_subscription_id, **kwargs):
        """
        Gets the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str announcement_subscription_id: (required)
            The OCID of the announcement subscription.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.AnnouncementSubscription`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/get_announcement_subscription.py.html>`__ to see an example of how to use get_announcement_subscription API.
        """
        resource_path = "/announcementSubscriptions/{announcementSubscriptionId}"
        method = "GET"
        operation_name = "get_announcement_subscription"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/GetAnnouncementSubscription"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "get_announcement_subscription got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementSubscriptionId": announcement_subscription_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="AnnouncementSubscription",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                response_type="AnnouncementSubscription",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def list_announcement_subscriptions(self, compartment_id, **kwargs):
        """
        Gets a list of all announcement subscriptions in the specified compartment.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str compartment_id: (required)
            The OCID of the compartment.

        :param str lifecycle_state: (optional)
            A filter to return only announcement subscriptions that match the given lifecycle state.

            Allowed values are: "ACTIVE", "DELETED", "FAILED"

        :param str display_name: (optional)
            A filter to return only resources that match the entire display name given.

        :param str id: (optional)
            The OCID of the announcement subscription.

        :param int limit: (optional)
            The maximum number of items to return in a paginated \"List\" call.

        :param str page: (optional)
            The value of the `opc-next-page` response header from the previous \"List\" call.

        :param str sort_order: (optional)
            The sort order to use, whether ascending ('ASC') or descending ('DESC').

            Allowed values are: "ASC", "DESC"

        :param str sort_by: (optional)
            The criteria to sort by. You can specify only one sort order. The default sort order for the creation date of resources is descending. The default sort order for display names is ascending.

            Allowed values are: "timeCreated", "displayName"

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.AnnouncementSubscriptionCollection`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/list_announcement_subscriptions.py.html>`__ to see an example of how to use list_announcement_subscriptions API.
        """
        resource_path = "/announcementSubscriptions"
        method = "GET"
        operation_name = "list_announcement_subscriptions"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscriptionCollection/ListAnnouncementSubscriptions"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "lifecycle_state",
            "display_name",
            "id",
            "limit",
            "page",
            "sort_order",
            "sort_by",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "list_announcement_subscriptions got unknown kwargs: {!r}".format(extra_kwargs))

        if 'lifecycle_state' in kwargs:
            lifecycle_state_allowed_values = ["ACTIVE", "DELETED", "FAILED"]
            if kwargs['lifecycle_state'] not in lifecycle_state_allowed_values:
                raise ValueError(
                    "Invalid value for `lifecycle_state`, must be one of {0}".format(lifecycle_state_allowed_values)
                )

        if 'sort_order' in kwargs:
            sort_order_allowed_values = ["ASC", "DESC"]
            if kwargs['sort_order'] not in sort_order_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_order`, must be one of {0}".format(sort_order_allowed_values)
                )

        if 'sort_by' in kwargs:
            sort_by_allowed_values = ["timeCreated", "displayName"]
            if kwargs['sort_by'] not in sort_by_allowed_values:
                raise ValueError(
                    "Invalid value for `sort_by`, must be one of {0}".format(sort_by_allowed_values)
                )

        query_params = {
            "compartmentId": compartment_id,
            "lifecycleState": kwargs.get("lifecycle_state", missing),
            "displayName": kwargs.get("display_name", missing),
            "id": kwargs.get("id", missing),
            "limit": kwargs.get("limit", missing),
            "page": kwargs.get("page", missing),
            "sortOrder": kwargs.get("sort_order", missing),
            "sortBy": kwargs.get("sort_by", missing)
        }
        query_params = {k: v for (k, v) in six.iteritems(query_params) if v is not missing and v is not None}

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="AnnouncementSubscriptionCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                query_params=query_params,
                header_params=header_params,
                response_type="AnnouncementSubscriptionCollection",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def update_announcement_subscription(self, announcement_subscription_id, update_announcement_subscription_details, **kwargs):
        """
        Updates the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str announcement_subscription_id: (required)
            The OCID of the announcement subscription.

        :param oci.announcements_service.models.UpdateAnnouncementSubscriptionDetails update_announcement_subscription_details: (required)
            The subscription information to update.

        :param str if_match: (optional)
            The locking version, used for optimistic concurrency control.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.AnnouncementSubscription`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/update_announcement_subscription.py.html>`__ to see an example of how to use update_announcement_subscription API.
        """
        resource_path = "/announcementSubscriptions/{announcementSubscriptionId}"
        method = "PUT"
        operation_name = "update_announcement_subscription"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/UpdateAnnouncementSubscription"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "if_match",
            "opc_request_id"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_announcement_subscription got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementSubscriptionId": announcement_subscription_id
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "if-match": kwargs.get("if_match", missing),
            "opc-request-id": kwargs.get("opc_request_id", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_announcement_subscription_details,
                response_type="AnnouncementSubscription",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_announcement_subscription_details,
                response_type="AnnouncementSubscription",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)

    def update_filter_group(self, announcement_subscription_id, filter_group_name, update_filter_group_details, **kwargs):
        """
        Updates a filter group in the specified announcement subscription.

        This call is subject to an Announcements limit that applies to the total number of requests across all read or write operations. Announcements might throttle this call to reject an otherwise valid request when the total rate of operations exceeds 20 requests per second for a given user. The service might also throttle this call to reject an otherwise valid request when the total rate of operations exceeds 100 requests per second for a given tenancy.


        :param str announcement_subscription_id: (required)
            The OCID of the announcement subscription.

        :param str filter_group_name: (required)
            The name of the filter group.

        :param oci.announcements_service.models.UpdateFilterGroupDetails update_filter_group_details: (required)
            The filter group information to update.

        :param str opc_request_id: (optional)
            The unique Oracle-assigned identifier for the request. If you need to contact Oracle about
            a particular request, please provide the complete request ID.

        :param str if_match: (optional)
            The locking version, used for optimistic concurrency control.

        :param obj retry_strategy: (optional)
            A retry strategy to apply to this specific operation/call. This will override any retry strategy set at the client-level.

            This should be one of the strategies available in the :py:mod:`~oci.retry` module. This operation will not retry by default, users can also use the convenient :py:data:`~oci.retry.DEFAULT_RETRY_STRATEGY` provided by the SDK to enable retries for it.
            The specifics of the default retry strategy are described `here <https://docs.oracle.com/en-us/iaas/tools/python/latest/sdk_behaviors/retries.html>`__.

            To have this operation explicitly not perform any retries, pass an instance of :py:class:`~oci.retry.NoneRetryStrategy`.

        :param bool allow_control_chars: (optional)
            allow_control_chars is a boolean to indicate whether or not this request should allow control characters in the response object.
            By default, the response will not allow control characters in strings

        :return: A :class:`~oci.response.Response` object with data of type :class:`~oci.announcements_service.models.FilterGroup`
        :rtype: :class:`~oci.response.Response`

        :example:
        Click `here <https://docs.cloud.oracle.com/en-us/iaas/tools/python-sdk-examples/2.70.1/announcementsservice/update_filter_group.py.html>`__ to see an example of how to use update_filter_group API.
        """
        resource_path = "/announcementSubscriptions/{announcementSubscriptionId}/filterGroups/{filterGroupName}"
        method = "PUT"
        operation_name = "update_filter_group"
        api_reference_link = "https://docs.oracle.com/iaas/api/#/en/announcements/0.0.1/AnnouncementSubscription/UpdateFilterGroup"

        # Don't accept unknown kwargs
        expected_kwargs = [
            "allow_control_chars",
            "retry_strategy",
            "opc_request_id",
            "if_match"
        ]
        extra_kwargs = [_key for _key in six.iterkeys(kwargs) if _key not in expected_kwargs]
        if extra_kwargs:
            raise ValueError(
                "update_filter_group got unknown kwargs: {!r}".format(extra_kwargs))

        path_params = {
            "announcementSubscriptionId": announcement_subscription_id,
            "filterGroupName": filter_group_name
        }

        path_params = {k: v for (k, v) in six.iteritems(path_params) if v is not missing}

        for (k, v) in six.iteritems(path_params):
            if v is None or (isinstance(v, six.string_types) and len(v.strip()) == 0):
                raise ValueError('Parameter {} cannot be None, whitespace or empty string'.format(k))

        header_params = {
            "accept": "application/json",
            "content-type": "application/json",
            "opc-request-id": kwargs.get("opc_request_id", missing),
            "if-match": kwargs.get("if_match", missing)
        }
        header_params = {k: v for (k, v) in six.iteritems(header_params) if v is not missing and v is not None}

        retry_strategy = self.base_client.get_preferred_retry_strategy(
            operation_retry_strategy=kwargs.get('retry_strategy'),
            client_retry_strategy=self.retry_strategy
        )

        if retry_strategy:
            if not isinstance(retry_strategy, retry.NoneRetryStrategy):
                self.base_client.add_opc_client_retries_header(header_params)
                retry_strategy.add_circuit_breaker_callback(self.circuit_breaker_callback)
            return retry_strategy.make_retrying_call(
                self.base_client.call_api,
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_filter_group_details,
                response_type="FilterGroup",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)
        else:
            return self.base_client.call_api(
                resource_path=resource_path,
                method=method,
                path_params=path_params,
                header_params=header_params,
                body=update_filter_group_details,
                response_type="FilterGroup",
                allow_control_chars=kwargs.get('allow_control_chars'),
                operation_name=operation_name,
                api_reference_link=api_reference_link)



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class TableSummary(object):
    """
    Details of a table fetched from the database.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new TableSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param table_name:
            The value to assign to the table_name property of this TableSummary.
        :type table_name: str

        :param schema_name:
            The value to assign to the schema_name property of this TableSummary.
        :type schema_name: str

        """
        self.swagger_types = {
            'table_name': 'str',
            'schema_name': 'str'
        }

        self.attribute_map = {
            'table_name': 'tableName',
            'schema_name': 'schemaName'
        }

        self._table_name = None
        self._schema_name = None

    @property
    def table_name(self):
        """
        **[Required]** Gets the table_name of this TableSummary.
        Name of the table.


        :return: The table_name of this TableSummary.
        :rtype: str
        """
        return self._table_name

    @table_name.setter
    def table_name(self, table_name):
        """
        Sets the table_name of this TableSummary.
        Name of the table.


        :param table_name: The table_name of this TableSummary.
        :type: str
        """
        self._table_name = table_name

    @property
    def schema_name(self):
        """
        **[Required]** Gets the schema_name of this TableSummary.
        Name of the schema.


        :return: The schema_name of this TableSummary.
        :rtype: str
        """
        return self._schema_name

    @schema_name.setter
    def schema_name(self, schema_name):
        """
        Sets the schema_name of this TableSummary.
        Name of the schema.


        :param schema_name: The schema_name of this TableSummary.
        :type: str
        """
        self._schema_name = schema_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BillToAddress(object):
    """
    Address details model
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BillToAddress object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param contact_name:
            The value to assign to the contact_name property of this BillToAddress.
        :type contact_name: str

        :param company_name:
            The value to assign to the company_name property of this BillToAddress.
        :type company_name: str

        :param address_line1:
            The value to assign to the address_line1 property of this BillToAddress.
        :type address_line1: str

        :param address_line2:
            The value to assign to the address_line2 property of this BillToAddress.
        :type address_line2: str

        :param address_line3:
            The value to assign to the address_line3 property of this BillToAddress.
        :type address_line3: str

        :param address_line4:
            The value to assign to the address_line4 property of this BillToAddress.
        :type address_line4: str

        :param street_name:
            The value to assign to the street_name property of this BillToAddress.
        :type street_name: str

        :param street_number:
            The value to assign to the street_number property of this BillToAddress.
        :type street_number: str

        :param city:
            The value to assign to the city property of this BillToAddress.
        :type city: str

        :param country:
            The value to assign to the country property of this BillToAddress.
        :type country: oci.osp_gateway.models.Country

        :param county:
            The value to assign to the county property of this BillToAddress.
        :type county: str

        :param state:
            The value to assign to the state property of this BillToAddress.
        :type state: str

        :param postal_code:
            The value to assign to the postal_code property of this BillToAddress.
        :type postal_code: str

        :param province:
            The value to assign to the province property of this BillToAddress.
        :type province: str

        """
        self.swagger_types = {
            'contact_name': 'str',
            'company_name': 'str',
            'address_line1': 'str',
            'address_line2': 'str',
            'address_line3': 'str',
            'address_line4': 'str',
            'street_name': 'str',
            'street_number': 'str',
            'city': 'str',
            'country': 'Country',
            'county': 'str',
            'state': 'str',
            'postal_code': 'str',
            'province': 'str'
        }

        self.attribute_map = {
            'contact_name': 'contactName',
            'company_name': 'companyName',
            'address_line1': 'addressLine1',
            'address_line2': 'addressLine2',
            'address_line3': 'addressLine3',
            'address_line4': 'addressLine4',
            'street_name': 'streetName',
            'street_number': 'streetNumber',
            'city': 'city',
            'country': 'country',
            'county': 'county',
            'state': 'state',
            'postal_code': 'postalCode',
            'province': 'province'
        }

        self._contact_name = None
        self._company_name = None
        self._address_line1 = None
        self._address_line2 = None
        self._address_line3 = None
        self._address_line4 = None
        self._street_name = None
        self._street_number = None
        self._city = None
        self._country = None
        self._county = None
        self._state = None
        self._postal_code = None
        self._province = None

    @property
    def contact_name(self):
        """
        Gets the contact_name of this BillToAddress.
        Name of the contact person


        :return: The contact_name of this BillToAddress.
        :rtype: str
        """
        return self._contact_name

    @contact_name.setter
    def contact_name(self, contact_name):
        """
        Sets the contact_name of this BillToAddress.
        Name of the contact person


        :param contact_name: The contact_name of this BillToAddress.
        :type: str
        """
        self._contact_name = contact_name

    @property
    def company_name(self):
        """
        Gets the company_name of this BillToAddress.
        Name of the customer company


        :return: The company_name of this BillToAddress.
        :rtype: str
        """
        return self._company_name

    @company_name.setter
    def company_name(self, company_name):
        """
        Sets the company_name of this BillToAddress.
        Name of the customer company


        :param company_name: The company_name of this BillToAddress.
        :type: str
        """
        self._company_name = company_name

    @property
    def address_line1(self):
        """
        Gets the address_line1 of this BillToAddress.
        Address line 1


        :return: The address_line1 of this BillToAddress.
        :rtype: str
        """
        return self._address_line1

    @address_line1.setter
    def address_line1(self, address_line1):
        """
        Sets the address_line1 of this BillToAddress.
        Address line 1


        :param address_line1: The address_line1 of this BillToAddress.
        :type: str
        """
        self._address_line1 = address_line1

    @property
    def address_line2(self):
        """
        Gets the address_line2 of this BillToAddress.
        Address line 2


        :return: The address_line2 of this BillToAddress.
        :rtype: str
        """
        return self._address_line2

    @address_line2.setter
    def address_line2(self, address_line2):
        """
        Sets the address_line2 of this BillToAddress.
        Address line 2


        :param address_line2: The address_line2 of this BillToAddress.
        :type: str
        """
        self._address_line2 = address_line2

    @property
    def address_line3(self):
        """
        Gets the address_line3 of this BillToAddress.
        Address line 3


        :return: The address_line3 of this BillToAddress.
        :rtype: str
        """
        return self._address_line3

    @address_line3.setter
    def address_line3(self, address_line3):
        """
        Sets the address_line3 of this BillToAddress.
        Address line 3


        :param address_line3: The address_line3 of this BillToAddress.
        :type: str
        """
        self._address_line3 = address_line3

    @property
    def address_line4(self):
        """
        Gets the address_line4 of this BillToAddress.
        Address line 4


        :return: The address_line4 of this BillToAddress.
        :rtype: str
        """
        return self._address_line4

    @address_line4.setter
    def address_line4(self, address_line4):
        """
        Sets the address_line4 of this BillToAddress.
        Address line 4


        :param address_line4: The address_line4 of this BillToAddress.
        :type: str
        """
        self._address_line4 = address_line4

    @property
    def street_name(self):
        """
        Gets the street_name of this BillToAddress.
        Street name


        :return: The street_name of this BillToAddress.
        :rtype: str
        """
        return self._street_name

    @street_name.setter
    def street_name(self, street_name):
        """
        Sets the street_name of this BillToAddress.
        Street name


        :param street_name: The street_name of this BillToAddress.
        :type: str
        """
        self._street_name = street_name

    @property
    def street_number(self):
        """
        Gets the street_number of this BillToAddress.
        House no


        :return: The street_number of this BillToAddress.
        :rtype: str
        """
        return self._street_number

    @street_number.setter
    def street_number(self, street_number):
        """
        Sets the street_number of this BillToAddress.
        House no


        :param street_number: The street_number of this BillToAddress.
        :type: str
        """
        self._street_number = street_number

    @property
    def city(self):
        """
        Gets the city of this BillToAddress.
        Name of the city


        :return: The city of this BillToAddress.
        :rtype: str
        """
        return self._city

    @city.setter
    def city(self, city):
        """
        Sets the city of this BillToAddress.
        Name of the city


        :param city: The city of this BillToAddress.
        :type: str
        """
        self._city = city

    @property
    def country(self):
        """
        Gets the country of this BillToAddress.

        :return: The country of this BillToAddress.
        :rtype: oci.osp_gateway.models.Country
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this BillToAddress.

        :param country: The country of this BillToAddress.
        :type: oci.osp_gateway.models.Country
        """
        self._country = country

    @property
    def county(self):
        """
        Gets the county of this BillToAddress.
        County name


        :return: The county of this BillToAddress.
        :rtype: str
        """
        return self._county

    @county.setter
    def county(self, county):
        """
        Sets the county of this BillToAddress.
        County name


        :param county: The county of this BillToAddress.
        :type: str
        """
        self._county = county

    @property
    def state(self):
        """
        Gets the state of this BillToAddress.
        Name of the state


        :return: The state of this BillToAddress.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this BillToAddress.
        Name of the state


        :param state: The state of this BillToAddress.
        :type: str
        """
        self._state = state

    @property
    def postal_code(self):
        """
        Gets the postal_code of this BillToAddress.
        ZIP no


        :return: The postal_code of this BillToAddress.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this BillToAddress.
        ZIP no


        :param postal_code: The postal_code of this BillToAddress.
        :type: str
        """
        self._postal_code = postal_code

    @property
    def province(self):
        """
        Gets the province of this BillToAddress.
        Name of the province


        :return: The province of this BillToAddress.
        :rtype: str
        """
        return self._province

    @province.setter
    def province(self, province):
        """
        Sets the province of this BillToAddress.
        Name of the province


        :param province: The province of this BillToAddress.
        :type: str
        """
        self._province = province

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class FieldMap(object):
    """
    A field map is a way to map a source row shape to a target row shape that may be different.
    """

    #: A constant which can be used with the model_type property of a FieldMap.
    #: This constant has a value of "DIRECT_NAMED_FIELD_MAP"
    MODEL_TYPE_DIRECT_NAMED_FIELD_MAP = "DIRECT_NAMED_FIELD_MAP"

    #: A constant which can be used with the model_type property of a FieldMap.
    #: This constant has a value of "COMPOSITE_FIELD_MAP"
    MODEL_TYPE_COMPOSITE_FIELD_MAP = "COMPOSITE_FIELD_MAP"

    #: A constant which can be used with the model_type property of a FieldMap.
    #: This constant has a value of "DIRECT_FIELD_MAP"
    MODEL_TYPE_DIRECT_FIELD_MAP = "DIRECT_FIELD_MAP"

    #: A constant which can be used with the model_type property of a FieldMap.
    #: This constant has a value of "RULE_BASED_FIELD_MAP"
    MODEL_TYPE_RULE_BASED_FIELD_MAP = "RULE_BASED_FIELD_MAP"

    #: A constant which can be used with the model_type property of a FieldMap.
    #: This constant has a value of "CONDITIONAL_COMPOSITE_FIELD_MAP"
    MODEL_TYPE_CONDITIONAL_COMPOSITE_FIELD_MAP = "CONDITIONAL_COMPOSITE_FIELD_MAP"

    #: A constant which can be used with the model_type property of a FieldMap.
    #: This constant has a value of "NAMED_ENTITY_MAP"
    MODEL_TYPE_NAMED_ENTITY_MAP = "NAMED_ENTITY_MAP"

    #: A constant which can be used with the model_type property of a FieldMap.
    #: This constant has a value of "RULE_BASED_ENTITY_MAP"
    MODEL_TYPE_RULE_BASED_ENTITY_MAP = "RULE_BASED_ENTITY_MAP"

    def __init__(self, **kwargs):
        """
        Initializes a new FieldMap object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_integration.models.RuleBasedFieldMap`
        * :class:`~oci.data_integration.models.RuleBasedEntityMap`
        * :class:`~oci.data_integration.models.NamedEntityMap`
        * :class:`~oci.data_integration.models.DirectFieldMap`
        * :class:`~oci.data_integration.models.CompositeFieldMap`
        * :class:`~oci.data_integration.models.ConditionalCompositeFieldMap`
        * :class:`~oci.data_integration.models.DirectNamedFieldMap`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param model_type:
            The value to assign to the model_type property of this FieldMap.
            Allowed values for this property are: "DIRECT_NAMED_FIELD_MAP", "COMPOSITE_FIELD_MAP", "DIRECT_FIELD_MAP", "RULE_BASED_FIELD_MAP", "CONDITIONAL_COMPOSITE_FIELD_MAP", "NAMED_ENTITY_MAP", "RULE_BASED_ENTITY_MAP", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type model_type: str

        :param description:
            The value to assign to the description property of this FieldMap.
        :type description: str

        """
        self.swagger_types = {
            'model_type': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'model_type': 'modelType',
            'description': 'description'
        }

        self._model_type = None
        self._description = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['modelType']

        if type == 'RULE_BASED_FIELD_MAP':
            return 'RuleBasedFieldMap'

        if type == 'RULE_BASED_ENTITY_MAP':
            return 'RuleBasedEntityMap'

        if type == 'NAMED_ENTITY_MAP':
            return 'NamedEntityMap'

        if type == 'DIRECT_FIELD_MAP':
            return 'DirectFieldMap'

        if type == 'COMPOSITE_FIELD_MAP':
            return 'CompositeFieldMap'

        if type == 'CONDITIONAL_COMPOSITE_FIELD_MAP':
            return 'ConditionalCompositeFieldMap'

        if type == 'DIRECT_NAMED_FIELD_MAP':
            return 'DirectNamedFieldMap'
        else:
            return 'FieldMap'

    @property
    def model_type(self):
        """
        **[Required]** Gets the model_type of this FieldMap.
        The model type for the field map.

        Allowed values for this property are: "DIRECT_NAMED_FIELD_MAP", "COMPOSITE_FIELD_MAP", "DIRECT_FIELD_MAP", "RULE_BASED_FIELD_MAP", "CONDITIONAL_COMPOSITE_FIELD_MAP", "NAMED_ENTITY_MAP", "RULE_BASED_ENTITY_MAP", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The model_type of this FieldMap.
        :rtype: str
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """
        Sets the model_type of this FieldMap.
        The model type for the field map.


        :param model_type: The model_type of this FieldMap.
        :type: str
        """
        allowed_values = ["DIRECT_NAMED_FIELD_MAP", "COMPOSITE_FIELD_MAP", "DIRECT_FIELD_MAP", "RULE_BASED_FIELD_MAP", "CONDITIONAL_COMPOSITE_FIELD_MAP", "NAMED_ENTITY_MAP", "RULE_BASED_ENTITY_MAP"]
        if not value_allowed_none_or_none_sentinel(model_type, allowed_values):
            model_type = 'UNKNOWN_ENUM_VALUE'
        self._model_type = model_type

    @property
    def description(self):
        """
        Gets the description of this FieldMap.
        Detailed description for the object.


        :return: The description of this FieldMap.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this FieldMap.
        Detailed description for the object.


        :param description: The description of this FieldMap.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Report(object):
    """
    Description of Report.
    """

    #: A constant which can be used with the mime_type property of a Report.
    #: This constant has a value of "PDF"
    MIME_TYPE_PDF = "PDF"

    #: A constant which can be used with the mime_type property of a Report.
    #: This constant has a value of "XLS"
    MIME_TYPE_XLS = "XLS"

    #: A constant which can be used with the lifecycle_state property of a Report.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a Report.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    def __init__(self, **kwargs):
        """
        Initializes a new Report object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this Report.
        :type id: str

        :param display_name:
            The value to assign to the display_name property of this Report.
        :type display_name: str

        :param report_definition_id:
            The value to assign to the report_definition_id property of this Report.
        :type report_definition_id: str

        :param description:
            The value to assign to the description property of this Report.
        :type description: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Report.
        :type compartment_id: str

        :param mime_type:
            The value to assign to the mime_type property of this Report.
            Allowed values for this property are: "PDF", "XLS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type mime_type: str

        :param time_generated:
            The value to assign to the time_generated property of this Report.
        :type time_generated: datetime

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this Report.
            Allowed values for this property are: "UPDATING", "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Report.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Report.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this Report.
        :type system_tags: dict(str, dict(str, object))

        """
        self.swagger_types = {
            'id': 'str',
            'display_name': 'str',
            'report_definition_id': 'str',
            'description': 'str',
            'compartment_id': 'str',
            'mime_type': 'str',
            'time_generated': 'datetime',
            'lifecycle_state': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))'
        }

        self.attribute_map = {
            'id': 'id',
            'display_name': 'displayName',
            'report_definition_id': 'reportDefinitionId',
            'description': 'description',
            'compartment_id': 'compartmentId',
            'mime_type': 'mimeType',
            'time_generated': 'timeGenerated',
            'lifecycle_state': 'lifecycleState',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags'
        }

        self._id = None
        self._display_name = None
        self._report_definition_id = None
        self._description = None
        self._compartment_id = None
        self._mime_type = None
        self._time_generated = None
        self._lifecycle_state = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this Report.
        The OCID of the report.


        :return: The id of this Report.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Report.
        The OCID of the report.


        :param id: The id of this Report.
        :type: str
        """
        self._id = id

    @property
    def display_name(self):
        """
        **[Required]** Gets the display_name of this Report.
        Name of the report.


        :return: The display_name of this Report.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this Report.
        Name of the report.


        :param display_name: The display_name of this Report.
        :type: str
        """
        self._display_name = display_name

    @property
    def report_definition_id(self):
        """
        Gets the report_definition_id of this Report.
        The OCID of the report definition.


        :return: The report_definition_id of this Report.
        :rtype: str
        """
        return self._report_definition_id

    @report_definition_id.setter
    def report_definition_id(self, report_definition_id):
        """
        Sets the report_definition_id of this Report.
        The OCID of the report definition.


        :param report_definition_id: The report_definition_id of this Report.
        :type: str
        """
        self._report_definition_id = report_definition_id

    @property
    def description(self):
        """
        Gets the description of this Report.
        Specifies a description of the report.


        :return: The description of this Report.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Report.
        Specifies a description of the report.


        :param description: The description of this Report.
        :type: str
        """
        self._description = description

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this Report.
        The OCID of the compartment containing the report.


        :return: The compartment_id of this Report.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Report.
        The OCID of the compartment containing the report.


        :param compartment_id: The compartment_id of this Report.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def mime_type(self):
        """
        Gets the mime_type of this Report.
        Specifies the format of report to be excel or pdf

        Allowed values for this property are: "PDF", "XLS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The mime_type of this Report.
        :rtype: str
        """
        return self._mime_type

    @mime_type.setter
    def mime_type(self, mime_type):
        """
        Sets the mime_type of this Report.
        Specifies the format of report to be excel or pdf


        :param mime_type: The mime_type of this Report.
        :type: str
        """
        allowed_values = ["PDF", "XLS"]
        if not value_allowed_none_or_none_sentinel(mime_type, allowed_values):
            mime_type = 'UNKNOWN_ENUM_VALUE'
        self._mime_type = mime_type

    @property
    def time_generated(self):
        """
        **[Required]** Gets the time_generated of this Report.
        Specifies the time at which the report was generated.


        :return: The time_generated of this Report.
        :rtype: datetime
        """
        return self._time_generated

    @time_generated.setter
    def time_generated(self, time_generated):
        """
        Sets the time_generated of this Report.
        Specifies the time at which the report was generated.


        :param time_generated: The time_generated of this Report.
        :type: datetime
        """
        self._time_generated = time_generated

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this Report.
        The current state of the report.

        Allowed values for this property are: "UPDATING", "ACTIVE", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this Report.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this Report.
        The current state of the report.


        :param lifecycle_state: The lifecycle_state of this Report.
        :type: str
        """
        allowed_values = ["UPDATING", "ACTIVE"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Report.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Report.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Report.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name, type, or namespace. For more information, see `Resource Tags`__

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Report.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Report.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Report.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Report.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more information, see `Resource Tags`__

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Report.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def system_tags(self):
        """
        Gets the system_tags of this Report.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :return: The system_tags of this Report.
        :rtype: dict(str, dict(str, object))
        """
        return self._system_tags

    @system_tags.setter
    def system_tags(self, system_tags):
        """
        Sets the system_tags of this Report.
        System tags for this resource. Each key is predefined and scoped to a namespace. For more information, see Resource Tags.
        Example: `{\"orcl-cloud\": {\"free-tier-retained\": \"true\"}}`


        :param system_tags: The system_tags of this Report.
        :type: dict(str, dict(str, object))
        """
        self._system_tags = system_tags

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AnnotationAnalyticsAggregationCollection(object):
    """
    Aggregation entities are required by the API consistency guidelines for API Consistency Guidelines#AnalyticsAPIs.  These are used to summarize annotations for a given dataset and will be used to populate UI elements.  Aggregations need to have the fields that identify the exact scope that they're summarizing.  Any filters applied to the list API, have to show up in the aggregation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AnnotationAnalyticsAggregationCollection object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param items:
            The value to assign to the items property of this AnnotationAnalyticsAggregationCollection.
        :type items: list[oci.data_labeling_service_dataplane.models.AnnotationAnalyticsAggregation]

        """
        self.swagger_types = {
            'items': 'list[AnnotationAnalyticsAggregation]'
        }

        self.attribute_map = {
            'items': 'items'
        }

        self._items = None

    @property
    def items(self):
        """
        **[Required]** Gets the items of this AnnotationAnalyticsAggregationCollection.
        The list of annotation entities.


        :return: The items of this AnnotationAnalyticsAggregationCollection.
        :rtype: list[oci.data_labeling_service_dataplane.models.AnnotationAnalyticsAggregation]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this AnnotationAnalyticsAggregationCollection.
        The list of annotation entities.


        :param items: The items of this AnnotationAnalyticsAggregationCollection.
        :type: list[oci.data_labeling_service_dataplane.models.AnnotationAnalyticsAggregation]
        """
        self._items = items

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_channel_result import CreateChannelResult
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateWebhookChannelResult(CreateChannelResult):
    """
    The configuration for a Webhook channel.
    """

    #: A constant which can be used with the payload_version property of a CreateWebhookChannelResult.
    #: This constant has a value of "1.0"
    PAYLOAD_VERSION_1_0 = "1.0"

    #: A constant which can be used with the payload_version property of a CreateWebhookChannelResult.
    #: This constant has a value of "1.1"
    PAYLOAD_VERSION_1_1 = "1.1"

    def __init__(self, **kwargs):
        """
        Initializes a new CreateWebhookChannelResult object with values from keyword arguments. The default value of the :py:attr:`~oci.oda.models.CreateWebhookChannelResult.type` attribute
        of this class is ``WEBHOOK`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this CreateWebhookChannelResult.
        :type id: str

        :param name:
            The value to assign to the name property of this CreateWebhookChannelResult.
        :type name: str

        :param description:
            The value to assign to the description property of this CreateWebhookChannelResult.
        :type description: str

        :param category:
            The value to assign to the category property of this CreateWebhookChannelResult.
            Allowed values for this property are: "AGENT", "APPLICATION", "BOT", "BOT_AS_AGENT", "SYSTEM", "EVENT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type category: str

        :param type:
            The value to assign to the type property of this CreateWebhookChannelResult.
            Allowed values for this property are: "ANDROID", "APPEVENT", "APPLICATION", "CORTANA", "FACEBOOK", "IOS", "MSTEAMS", "OSS", "OSVC", "SERVICECLOUD", "SLACK", "TEST", "TWILIO", "WEB", "WEBHOOK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        :param session_expiry_duration_in_milliseconds:
            The value to assign to the session_expiry_duration_in_milliseconds property of this CreateWebhookChannelResult.
        :type session_expiry_duration_in_milliseconds: int

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this CreateWebhookChannelResult.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "INACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param time_created:
            The value to assign to the time_created property of this CreateWebhookChannelResult.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this CreateWebhookChannelResult.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this CreateWebhookChannelResult.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this CreateWebhookChannelResult.
        :type defined_tags: dict(str, dict(str, object))

        :param secret_key:
            The value to assign to the secret_key property of this CreateWebhookChannelResult.
        :type secret_key: str

        :param outbound_url:
            The value to assign to the outbound_url property of this CreateWebhookChannelResult.
        :type outbound_url: str

        :param payload_version:
            The value to assign to the payload_version property of this CreateWebhookChannelResult.
            Allowed values for this property are: "1.0", "1.1", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type payload_version: str

        :param bot_id:
            The value to assign to the bot_id property of this CreateWebhookChannelResult.
        :type bot_id: str

        :param webhook_url:
            The value to assign to the webhook_url property of this CreateWebhookChannelResult.
        :type webhook_url: str

        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'description': 'str',
            'category': 'str',
            'type': 'str',
            'session_expiry_duration_in_milliseconds': 'int',
            'lifecycle_state': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'secret_key': 'str',
            'outbound_url': 'str',
            'payload_version': 'str',
            'bot_id': 'str',
            'webhook_url': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'description': 'description',
            'category': 'category',
            'type': 'type',
            'session_expiry_duration_in_milliseconds': 'sessionExpiryDurationInMilliseconds',
            'lifecycle_state': 'lifecycleState',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'secret_key': 'secretKey',
            'outbound_url': 'outboundUrl',
            'payload_version': 'payloadVersion',
            'bot_id': 'botId',
            'webhook_url': 'webhookUrl'
        }

        self._id = None
        self._name = None
        self._description = None
        self._category = None
        self._type = None
        self._session_expiry_duration_in_milliseconds = None
        self._lifecycle_state = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None
        self._secret_key = None
        self._outbound_url = None
        self._payload_version = None
        self._bot_id = None
        self._webhook_url = None
        self._type = 'WEBHOOK'

    @property
    def secret_key(self):
        """
        **[Required]** Gets the secret_key of this CreateWebhookChannelResult.
        The secret key used to verify the authenticity of received messages.
        This is only returned this once.  If it is lost the keys will need to be rotated to generate a new key.


        :return: The secret_key of this CreateWebhookChannelResult.
        :rtype: str
        """
        return self._secret_key

    @secret_key.setter
    def secret_key(self, secret_key):
        """
        Sets the secret_key of this CreateWebhookChannelResult.
        The secret key used to verify the authenticity of received messages.
        This is only returned this once.  If it is lost the keys will need to be rotated to generate a new key.


        :param secret_key: The secret_key of this CreateWebhookChannelResult.
        :type: str
        """
        self._secret_key = secret_key

    @property
    def outbound_url(self):
        """
        **[Required]** Gets the outbound_url of this CreateWebhookChannelResult.
        The URL to send responses to.


        :return: The outbound_url of this CreateWebhookChannelResult.
        :rtype: str
        """
        return self._outbound_url

    @outbound_url.setter
    def outbound_url(self, outbound_url):
        """
        Sets the outbound_url of this CreateWebhookChannelResult.
        The URL to send responses to.


        :param outbound_url: The outbound_url of this CreateWebhookChannelResult.
        :type: str
        """
        self._outbound_url = outbound_url

    @property
    def payload_version(self):
        """
        **[Required]** Gets the payload_version of this CreateWebhookChannelResult.
        The version for payloads.

        Allowed values for this property are: "1.0", "1.1", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The payload_version of this CreateWebhookChannelResult.
        :rtype: str
        """
        return self._payload_version

    @payload_version.setter
    def payload_version(self, payload_version):
        """
        Sets the payload_version of this CreateWebhookChannelResult.
        The version for payloads.


        :param payload_version: The payload_version of this CreateWebhookChannelResult.
        :type: str
        """
        allowed_values = ["1.0", "1.1"]
        if not value_allowed_none_or_none_sentinel(payload_version, allowed_values):
            payload_version = 'UNKNOWN_ENUM_VALUE'
        self._payload_version = payload_version

    @property
    def bot_id(self):
        """
        Gets the bot_id of this CreateWebhookChannelResult.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :return: The bot_id of this CreateWebhookChannelResult.
        :rtype: str
        """
        return self._bot_id

    @bot_id.setter
    def bot_id(self, bot_id):
        """
        Sets the bot_id of this CreateWebhookChannelResult.
        The ID of the Skill or Digital Assistant that the Channel is routed to.


        :param bot_id: The bot_id of this CreateWebhookChannelResult.
        :type: str
        """
        self._bot_id = bot_id

    @property
    def webhook_url(self):
        """
        **[Required]** Gets the webhook_url of this CreateWebhookChannelResult.
        The URL to use to send messages to this channel.
        This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.


        :return: The webhook_url of this CreateWebhookChannelResult.
        :rtype: str
        """
        return self._webhook_url

    @webhook_url.setter
    def webhook_url(self, webhook_url):
        """
        Sets the webhook_url of this CreateWebhookChannelResult.
        The URL to use to send messages to this channel.
        This will be generally be used to configure a webhook in a 3rd party messaging system to send messages to this channel.


        :param webhook_url: The webhook_url of this CreateWebhookChannelResult.
        :type: str
        """
        self._webhook_url = webhook_url

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .config_summary import ConfigSummary
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ApdexRulesSummary(ConfigSummary):
    """
    The set of Apdex rules used in Apdex computation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ApdexRulesSummary object with values from keyword arguments. The default value of the :py:attr:`~oci.apm_config.models.ApdexRulesSummary.config_type` attribute
        of this class is ``APDEX`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this ApdexRulesSummary.
        :type id: str

        :param config_type:
            The value to assign to the config_type property of this ApdexRulesSummary.
            Allowed values for this property are: "SPAN_FILTER", "METRIC_GROUP", "APDEX"
        :type config_type: str

        :param time_created:
            The value to assign to the time_created property of this ApdexRulesSummary.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this ApdexRulesSummary.
        :type time_updated: datetime

        :param freeform_tags:
            The value to assign to the freeform_tags property of this ApdexRulesSummary.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this ApdexRulesSummary.
        :type defined_tags: dict(str, dict(str, object))

        :param rules:
            The value to assign to the rules property of this ApdexRulesSummary.
        :type rules: list[oci.apm_config.models.Apdex]

        :param display_name:
            The value to assign to the display_name property of this ApdexRulesSummary.
        :type display_name: str

        """
        self.swagger_types = {
            'id': 'str',
            'config_type': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'rules': 'list[Apdex]',
            'display_name': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'config_type': 'configType',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'rules': 'rules',
            'display_name': 'displayName'
        }

        self._id = None
        self._config_type = None
        self._time_created = None
        self._time_updated = None
        self._freeform_tags = None
        self._defined_tags = None
        self._rules = None
        self._display_name = None
        self._config_type = 'APDEX'

    @property
    def rules(self):
        """
        Gets the rules of this ApdexRulesSummary.

        :return: The rules of this ApdexRulesSummary.
        :rtype: list[oci.apm_config.models.Apdex]
        """
        return self._rules

    @rules.setter
    def rules(self, rules):
        """
        Sets the rules of this ApdexRulesSummary.

        :param rules: The rules of this ApdexRulesSummary.
        :type: list[oci.apm_config.models.Apdex]
        """
        self._rules = rules

    @property
    def display_name(self):
        """
        Gets the display_name of this ApdexRulesSummary.
        The name by which the rule set is displayed to the end user.


        :return: The display_name of this ApdexRulesSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this ApdexRulesSummary.
        The name by which the rule set is displayed to the end user.


        :param display_name: The display_name of this ApdexRulesSummary.
        :type: str
        """
        self._display_name = display_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class RuleAttribute(object):
    """
    Object that defines a usage of an attribute in the context of a rule.
    Example: For a UNIQUEKEY rule, declares the attribute in a table whose value must be unique.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new RuleAttribute object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this RuleAttribute.
        :type key: str

        :param display_name:
            The value to assign to the display_name property of this RuleAttribute.
        :type display_name: str

        :param position:
            The value to assign to the position property of this RuleAttribute.
        :type position: int

        """
        self.swagger_types = {
            'key': 'str',
            'display_name': 'str',
            'position': 'int'
        }

        self.attribute_map = {
            'key': 'key',
            'display_name': 'displayName',
            'position': 'position'
        }

        self._key = None
        self._display_name = None
        self._position = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this RuleAttribute.
        Immutable unique key of the attribute.


        :return: The key of this RuleAttribute.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this RuleAttribute.
        Immutable unique key of the attribute.


        :param key: The key of this RuleAttribute.
        :type: str
        """
        self._key = key

    @property
    def display_name(self):
        """
        Gets the display_name of this RuleAttribute.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this RuleAttribute.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this RuleAttribute.
        A user-friendly display name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this RuleAttribute.
        :type: str
        """
        self._display_name = display_name

    @property
    def position(self):
        """
        Gets the position of this RuleAttribute.
        Position of the attribute in the record definition.


        :return: The position of this RuleAttribute.
        :rtype: int
        """
        return self._position

    @position.setter
    def position(self, position):
        """
        Sets the position of this RuleAttribute.
        Position of the attribute in the record definition.


        :param position: The position of this RuleAttribute.
        :type: int
        """
        self._position = position

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryProperties(object):
    """
    The query properties.
    """

    #: A constant which can be used with the granularity property of a QueryProperties.
    #: This constant has a value of "DAILY"
    GRANULARITY_DAILY = "DAILY"

    #: A constant which can be used with the granularity property of a QueryProperties.
    #: This constant has a value of "MONTHLY"
    GRANULARITY_MONTHLY = "MONTHLY"

    #: A constant which can be used with the query_type property of a QueryProperties.
    #: This constant has a value of "USAGE"
    QUERY_TYPE_USAGE = "USAGE"

    #: A constant which can be used with the query_type property of a QueryProperties.
    #: This constant has a value of "COST"
    QUERY_TYPE_COST = "COST"

    #: A constant which can be used with the query_type property of a QueryProperties.
    #: This constant has a value of "USAGE_AND_COST"
    QUERY_TYPE_USAGE_AND_COST = "USAGE_AND_COST"

    def __init__(self, **kwargs):
        """
        Initializes a new QueryProperties object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param group_by:
            The value to assign to the group_by property of this QueryProperties.
        :type group_by: list[str]

        :param group_by_tag:
            The value to assign to the group_by_tag property of this QueryProperties.
        :type group_by_tag: list[oci.usage_api.models.Tag]

        :param filter:
            The value to assign to the filter property of this QueryProperties.
        :type filter: oci.usage_api.models.Filter

        :param compartment_depth:
            The value to assign to the compartment_depth property of this QueryProperties.
        :type compartment_depth: float

        :param granularity:
            The value to assign to the granularity property of this QueryProperties.
            Allowed values for this property are: "DAILY", "MONTHLY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type granularity: str

        :param query_type:
            The value to assign to the query_type property of this QueryProperties.
            Allowed values for this property are: "USAGE", "COST", "USAGE_AND_COST", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type query_type: str

        :param is_aggregate_by_time:
            The value to assign to the is_aggregate_by_time property of this QueryProperties.
        :type is_aggregate_by_time: bool

        :param date_range:
            The value to assign to the date_range property of this QueryProperties.
        :type date_range: oci.usage_api.models.DateRange

        """
        self.swagger_types = {
            'group_by': 'list[str]',
            'group_by_tag': 'list[Tag]',
            'filter': 'Filter',
            'compartment_depth': 'float',
            'granularity': 'str',
            'query_type': 'str',
            'is_aggregate_by_time': 'bool',
            'date_range': 'DateRange'
        }

        self.attribute_map = {
            'group_by': 'groupBy',
            'group_by_tag': 'groupByTag',
            'filter': 'filter',
            'compartment_depth': 'compartmentDepth',
            'granularity': 'granularity',
            'query_type': 'queryType',
            'is_aggregate_by_time': 'isAggregateByTime',
            'date_range': 'dateRange'
        }

        self._group_by = None
        self._group_by_tag = None
        self._filter = None
        self._compartment_depth = None
        self._granularity = None
        self._query_type = None
        self._is_aggregate_by_time = None
        self._date_range = None

    @property
    def group_by(self):
        """
        Gets the group_by of this QueryProperties.
        Aggregate the result by. For example: [ \"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\", \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\", \"resourceId\", \"tenantId\", \"tenantName\" ]


        :return: The group_by of this QueryProperties.
        :rtype: list[str]
        """
        return self._group_by

    @group_by.setter
    def group_by(self, group_by):
        """
        Sets the group_by of this QueryProperties.
        Aggregate the result by. For example: [ \"tagNamespace\", \"tagKey\", \"tagValue\", \"service\", \"skuName\", \"skuPartNumber\", \"unit\", \"compartmentName\", \"compartmentPath\", \"compartmentId\", \"platform\", \"region\", \"logicalAd\", \"resourceId\", \"tenantId\", \"tenantName\" ]


        :param group_by: The group_by of this QueryProperties.
        :type: list[str]
        """
        self._group_by = group_by

    @property
    def group_by_tag(self):
        """
        Gets the group_by_tag of this QueryProperties.
        GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only supports one tag in the list. For example: [ { \"namespace\": \"oracle\", \"key\": \"createdBy\" ]


        :return: The group_by_tag of this QueryProperties.
        :rtype: list[oci.usage_api.models.Tag]
        """
        return self._group_by_tag

    @group_by_tag.setter
    def group_by_tag(self, group_by_tag):
        """
        Sets the group_by_tag of this QueryProperties.
        GroupBy a specific tagKey. Provide the tagNamespace and tagKey in the tag object. Only supports one tag in the list. For example: [ { \"namespace\": \"oracle\", \"key\": \"createdBy\" ]


        :param group_by_tag: The group_by_tag of this QueryProperties.
        :type: list[oci.usage_api.models.Tag]
        """
        self._group_by_tag = group_by_tag

    @property
    def filter(self):
        """
        Gets the filter of this QueryProperties.

        :return: The filter of this QueryProperties.
        :rtype: oci.usage_api.models.Filter
        """
        return self._filter

    @filter.setter
    def filter(self, filter):
        """
        Sets the filter of this QueryProperties.

        :param filter: The filter of this QueryProperties.
        :type: oci.usage_api.models.Filter
        """
        self._filter = filter

    @property
    def compartment_depth(self):
        """
        Gets the compartment_depth of this QueryProperties.
        The depth level of the compartment.


        :return: The compartment_depth of this QueryProperties.
        :rtype: float
        """
        return self._compartment_depth

    @compartment_depth.setter
    def compartment_depth(self, compartment_depth):
        """
        Sets the compartment_depth of this QueryProperties.
        The depth level of the compartment.


        :param compartment_depth: The compartment_depth of this QueryProperties.
        :type: float
        """
        self._compartment_depth = compartment_depth

    @property
    def granularity(self):
        """
        **[Required]** Gets the granularity of this QueryProperties.
        The usage granularity. DAILY - Daily data aggregation. MONTHLY - Monthly data aggregation.
        Allowed values are:
          DAILY
          MONTHLY

        Allowed values for this property are: "DAILY", "MONTHLY", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The granularity of this QueryProperties.
        :rtype: str
        """
        return self._granularity

    @granularity.setter
    def granularity(self, granularity):
        """
        Sets the granularity of this QueryProperties.
        The usage granularity. DAILY - Daily data aggregation. MONTHLY - Monthly data aggregation.
        Allowed values are:
          DAILY
          MONTHLY


        :param granularity: The granularity of this QueryProperties.
        :type: str
        """
        allowed_values = ["DAILY", "MONTHLY"]
        if not value_allowed_none_or_none_sentinel(granularity, allowed_values):
            granularity = 'UNKNOWN_ENUM_VALUE'
        self._granularity = granularity

    @property
    def query_type(self):
        """
        Gets the query_type of this QueryProperties.
        The query usage type. COST by default if it is missing. Usage - Query the usage data. Cost - Query the cost/billing data.
        Allowed values are:
          USAGE
          COST
          USAGE_AND_COST

        Allowed values for this property are: "USAGE", "COST", "USAGE_AND_COST", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The query_type of this QueryProperties.
        :rtype: str
        """
        return self._query_type

    @query_type.setter
    def query_type(self, query_type):
        """
        Sets the query_type of this QueryProperties.
        The query usage type. COST by default if it is missing. Usage - Query the usage data. Cost - Query the cost/billing data.
        Allowed values are:
          USAGE
          COST
          USAGE_AND_COST


        :param query_type: The query_type of this QueryProperties.
        :type: str
        """
        allowed_values = ["USAGE", "COST", "USAGE_AND_COST"]
        if not value_allowed_none_or_none_sentinel(query_type, allowed_values):
            query_type = 'UNKNOWN_ENUM_VALUE'
        self._query_type = query_type

    @property
    def is_aggregate_by_time(self):
        """
        Gets the is_aggregate_by_time of this QueryProperties.
        Specifies whether aggregated by time. If isAggregateByTime is true, all usage/cost over the query time period will be added up.


        :return: The is_aggregate_by_time of this QueryProperties.
        :rtype: bool
        """
        return self._is_aggregate_by_time

    @is_aggregate_by_time.setter
    def is_aggregate_by_time(self, is_aggregate_by_time):
        """
        Sets the is_aggregate_by_time of this QueryProperties.
        Specifies whether aggregated by time. If isAggregateByTime is true, all usage/cost over the query time period will be added up.


        :param is_aggregate_by_time: The is_aggregate_by_time of this QueryProperties.
        :type: bool
        """
        self._is_aggregate_by_time = is_aggregate_by_time

    @property
    def date_range(self):
        """
        **[Required]** Gets the date_range of this QueryProperties.

        :return: The date_range of this QueryProperties.
        :rtype: oci.usage_api.models.DateRange
        """
        return self._date_range

    @date_range.setter
    def date_range(self, date_range):
        """
        Sets the date_range of this QueryProperties.

        :param date_range: The date_range of this QueryProperties.
        :type: oci.usage_api.models.DateRange
        """
        self._date_range = date_range

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Attribute(object):
    """
    Registry Attribute Object, to get connector details
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Attribute object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this Attribute.
        :type name: str

        :param is_sensitive:
            The value to assign to the is_sensitive property of this Attribute.
        :type is_sensitive: bool

        :param is_mandatory:
            The value to assign to the is_mandatory property of this Attribute.
        :type is_mandatory: bool

        :param is_generated:
            The value to assign to the is_generated property of this Attribute.
        :type is_generated: bool

        :param is_base64_encoded:
            The value to assign to the is_base64_encoded property of this Attribute.
        :type is_base64_encoded: bool

        :param valid_key_list:
            The value to assign to the valid_key_list property of this Attribute.
        :type valid_key_list: list[str]

        :param attribute_type:
            The value to assign to the attribute_type property of this Attribute.
        :type attribute_type: str

        """
        self.swagger_types = {
            'name': 'str',
            'is_sensitive': 'bool',
            'is_mandatory': 'bool',
            'is_generated': 'bool',
            'is_base64_encoded': 'bool',
            'valid_key_list': 'list[str]',
            'attribute_type': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'is_sensitive': 'isSensitive',
            'is_mandatory': 'isMandatory',
            'is_generated': 'isGenerated',
            'is_base64_encoded': 'isBase64Encoded',
            'valid_key_list': 'validKeyList',
            'attribute_type': 'attributeType'
        }

        self._name = None
        self._is_sensitive = None
        self._is_mandatory = None
        self._is_generated = None
        self._is_base64_encoded = None
        self._valid_key_list = None
        self._attribute_type = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this Attribute.
        The name of of the Attribute.


        :return: The name of this Attribute.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Attribute.
        The name of of the Attribute.


        :param name: The name of this Attribute.
        :type: str
        """
        self._name = name

    @property
    def is_sensitive(self):
        """
        Gets the is_sensitive of this Attribute.
        True if Attribute is sensitive.


        :return: The is_sensitive of this Attribute.
        :rtype: bool
        """
        return self._is_sensitive

    @is_sensitive.setter
    def is_sensitive(self, is_sensitive):
        """
        Sets the is_sensitive of this Attribute.
        True if Attribute is sensitive.


        :param is_sensitive: The is_sensitive of this Attribute.
        :type: bool
        """
        self._is_sensitive = is_sensitive

    @property
    def is_mandatory(self):
        """
        Gets the is_mandatory of this Attribute.
        True if Attribute is mandatory.


        :return: The is_mandatory of this Attribute.
        :rtype: bool
        """
        return self._is_mandatory

    @is_mandatory.setter
    def is_mandatory(self, is_mandatory):
        """
        Sets the is_mandatory of this Attribute.
        True if Attribute is mandatory.


        :param is_mandatory: The is_mandatory of this Attribute.
        :type: bool
        """
        self._is_mandatory = is_mandatory

    @property
    def is_generated(self):
        """
        Gets the is_generated of this Attribute.
        True if Attribute is generated.


        :return: The is_generated of this Attribute.
        :rtype: bool
        """
        return self._is_generated

    @is_generated.setter
    def is_generated(self, is_generated):
        """
        Sets the is_generated of this Attribute.
        True if Attribute is generated.


        :param is_generated: The is_generated of this Attribute.
        :type: bool
        """
        self._is_generated = is_generated

    @property
    def is_base64_encoded(self):
        """
        Gets the is_base64_encoded of this Attribute.
        True if Attribute is encoded.


        :return: The is_base64_encoded of this Attribute.
        :rtype: bool
        """
        return self._is_base64_encoded

    @is_base64_encoded.setter
    def is_base64_encoded(self, is_base64_encoded):
        """
        Sets the is_base64_encoded of this Attribute.
        True if Attribute is encoded.


        :param is_base64_encoded: The is_base64_encoded of this Attribute.
        :type: bool
        """
        self._is_base64_encoded = is_base64_encoded

    @property
    def valid_key_list(self):
        """
        Gets the valid_key_list of this Attribute.
        List of valid key list


        :return: The valid_key_list of this Attribute.
        :rtype: list[str]
        """
        return self._valid_key_list

    @valid_key_list.setter
    def valid_key_list(self, valid_key_list):
        """
        Sets the valid_key_list of this Attribute.
        List of valid key list


        :param valid_key_list: The valid_key_list of this Attribute.
        :type: list[str]
        """
        self._valid_key_list = valid_key_list

    @property
    def attribute_type(self):
        """
        Gets the attribute_type of this Attribute.
        Attribute type details


        :return: The attribute_type of this Attribute.
        :rtype: str
        """
        return self._attribute_type

    @attribute_type.setter
    def attribute_type(self, attribute_type):
        """
        Sets the attribute_type of this Attribute.
        Attribute type details


        :param attribute_type: The attribute_type of this Attribute.
        :type: str
        """
        self._attribute_type = attribute_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateToken(object):
    """
    ODMS Agent token details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateToken object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param rpt_blob:
            The value to assign to the rpt_blob property of this GenerateToken.
        :type rpt_blob: str

        """
        self.swagger_types = {
            'rpt_blob': 'str'
        }

        self.attribute_map = {
            'rpt_blob': 'rptBlob'
        }

        self._rpt_blob = None

    @property
    def rpt_blob(self):
        """
        **[Required]** Gets the rpt_blob of this GenerateToken.
        Resource Principals Token in serialized form.


        :return: The rpt_blob of this GenerateToken.
        :rtype: str
        """
        return self._rpt_blob

    @rpt_blob.setter
    def rpt_blob(self, rpt_blob):
        """
        Sets the rpt_blob of this GenerateToken.
        Resource Principals Token in serialized form.


        :param rpt_blob: The rpt_blob of this GenerateToken.
        :type: str
        """
        self._rpt_blob = rpt_blob

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .sensitive_type import SensitiveType
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SensitiveTypePattern(SensitiveType):
    """
    Details of the sensitive type.
    """

    #: A constant which can be used with the search_type property of a SensitiveTypePattern.
    #: This constant has a value of "OR"
    SEARCH_TYPE_OR = "OR"

    #: A constant which can be used with the search_type property of a SensitiveTypePattern.
    #: This constant has a value of "AND"
    SEARCH_TYPE_AND = "AND"

    def __init__(self, **kwargs):
        """
        Initializes a new SensitiveTypePattern object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.SensitiveTypePattern.entity_type` attribute
        of this class is ``SENSITIVE_TYPE`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SensitiveTypePattern.
        :type id: str

        :param entity_type:
            The value to assign to the entity_type property of this SensitiveTypePattern.
            Allowed values for this property are: "SENSITIVE_TYPE", "SENSITIVE_CATEGORY", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_type: str

        :param display_name:
            The value to assign to the display_name property of this SensitiveTypePattern.
        :type display_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this SensitiveTypePattern.
        :type compartment_id: str

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SensitiveTypePattern.
            Allowed values for this property are: "CREATING", "ACTIVE", "UPDATING", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        :param short_name:
            The value to assign to the short_name property of this SensitiveTypePattern.
        :type short_name: str

        :param source:
            The value to assign to the source property of this SensitiveTypePattern.
            Allowed values for this property are: "ORACLE", "USER", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type source: str

        :param time_created:
            The value to assign to the time_created property of this SensitiveTypePattern.
        :type time_created: datetime

        :param time_updated:
            The value to assign to the time_updated property of this SensitiveTypePattern.
        :type time_updated: datetime

        :param description:
            The value to assign to the description property of this SensitiveTypePattern.
        :type description: str

        :param parent_category_id:
            The value to assign to the parent_category_id property of this SensitiveTypePattern.
        :type parent_category_id: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this SensitiveTypePattern.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this SensitiveTypePattern.
        :type defined_tags: dict(str, dict(str, object))

        :param system_tags:
            The value to assign to the system_tags property of this SensitiveTypePattern.
        :type system_tags: dict(str, dict(str, object))

        :param name_pattern:
            The value to assign to the name_pattern property of this SensitiveTypePattern.
        :type name_pattern: str

        :param comment_pattern:
            The value to assign to the comment_pattern property of this SensitiveTypePattern.
        :type comment_pattern: str

        :param data_pattern:
            The value to assign to the data_pattern property of this SensitiveTypePattern.
        :type data_pattern: str

        :param search_type:
            The value to assign to the search_type property of this SensitiveTypePattern.
            Allowed values for this property are: "OR", "AND", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type search_type: str

        :param default_masking_format_id:
            The value to assign to the default_masking_format_id property of this SensitiveTypePattern.
        :type default_masking_format_id: str

        """
        self.swagger_types = {
            'id': 'str',
            'entity_type': 'str',
            'display_name': 'str',
            'compartment_id': 'str',
            'lifecycle_state': 'str',
            'short_name': 'str',
            'source': 'str',
            'time_created': 'datetime',
            'time_updated': 'datetime',
            'description': 'str',
            'parent_category_id': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'system_tags': 'dict(str, dict(str, object))',
            'name_pattern': 'str',
            'comment_pattern': 'str',
            'data_pattern': 'str',
            'search_type': 'str',
            'default_masking_format_id': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'entity_type': 'entityType',
            'display_name': 'displayName',
            'compartment_id': 'compartmentId',
            'lifecycle_state': 'lifecycleState',
            'short_name': 'shortName',
            'source': 'source',
            'time_created': 'timeCreated',
            'time_updated': 'timeUpdated',
            'description': 'description',
            'parent_category_id': 'parentCategoryId',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'system_tags': 'systemTags',
            'name_pattern': 'namePattern',
            'comment_pattern': 'commentPattern',
            'data_pattern': 'dataPattern',
            'search_type': 'searchType',
            'default_masking_format_id': 'defaultMaskingFormatId'
        }

        self._id = None
        self._entity_type = None
        self._display_name = None
        self._compartment_id = None
        self._lifecycle_state = None
        self._short_name = None
        self._source = None
        self._time_created = None
        self._time_updated = None
        self._description = None
        self._parent_category_id = None
        self._freeform_tags = None
        self._defined_tags = None
        self._system_tags = None
        self._name_pattern = None
        self._comment_pattern = None
        self._data_pattern = None
        self._search_type = None
        self._default_masking_format_id = None
        self._entity_type = 'SENSITIVE_TYPE'

    @property
    def name_pattern(self):
        """
        Gets the name_pattern of this SensitiveTypePattern.
        A regular expression to be used by data discovery for matching column names.


        :return: The name_pattern of this SensitiveTypePattern.
        :rtype: str
        """
        return self._name_pattern

    @name_pattern.setter
    def name_pattern(self, name_pattern):
        """
        Sets the name_pattern of this SensitiveTypePattern.
        A regular expression to be used by data discovery for matching column names.


        :param name_pattern: The name_pattern of this SensitiveTypePattern.
        :type: str
        """
        self._name_pattern = name_pattern

    @property
    def comment_pattern(self):
        """
        Gets the comment_pattern of this SensitiveTypePattern.
        A regular expression to be used by data discovery for matching column comments.


        :return: The comment_pattern of this SensitiveTypePattern.
        :rtype: str
        """
        return self._comment_pattern

    @comment_pattern.setter
    def comment_pattern(self, comment_pattern):
        """
        Sets the comment_pattern of this SensitiveTypePattern.
        A regular expression to be used by data discovery for matching column comments.


        :param comment_pattern: The comment_pattern of this SensitiveTypePattern.
        :type: str
        """
        self._comment_pattern = comment_pattern

    @property
    def data_pattern(self):
        """
        Gets the data_pattern of this SensitiveTypePattern.
        A regular expression to be used by data discovery for matching column data values.


        :return: The data_pattern of this SensitiveTypePattern.
        :rtype: str
        """
        return self._data_pattern

    @data_pattern.setter
    def data_pattern(self, data_pattern):
        """
        Sets the data_pattern of this SensitiveTypePattern.
        A regular expression to be used by data discovery for matching column data values.


        :param data_pattern: The data_pattern of this SensitiveTypePattern.
        :type: str
        """
        self._data_pattern = data_pattern

    @property
    def search_type(self):
        """
        Gets the search_type of this SensitiveTypePattern.
        The search type indicating how the column name, comment and data patterns should be used by data discovery.
        `Learn more`__.

        __ https://docs.oracle.com/en/cloud/paas/data-safe/udscs/sensitive-types.html#GUID-1D1AD98E-B93F-4FF2-80AE-CB7D8A14F6CC

        Allowed values for this property are: "OR", "AND", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The search_type of this SensitiveTypePattern.
        :rtype: str
        """
        return self._search_type

    @search_type.setter
    def search_type(self, search_type):
        """
        Sets the search_type of this SensitiveTypePattern.
        The search type indicating how the column name, comment and data patterns should be used by data discovery.
        `Learn more`__.

        __ https://docs.oracle.com/en/cloud/paas/data-safe/udscs/sensitive-types.html#GUID-1D1AD98E-B93F-4FF2-80AE-CB7D8A14F6CC


        :param search_type: The search_type of this SensitiveTypePattern.
        :type: str
        """
        allowed_values = ["OR", "AND"]
        if not value_allowed_none_or_none_sentinel(search_type, allowed_values):
            search_type = 'UNKNOWN_ENUM_VALUE'
        self._search_type = search_type

    @property
    def default_masking_format_id(self):
        """
        Gets the default_masking_format_id of this SensitiveTypePattern.
        The OCID of the library masking format that should be used to mask the sensitive columns associated with the sensitive type.


        :return: The default_masking_format_id of this SensitiveTypePattern.
        :rtype: str
        """
        return self._default_masking_format_id

    @default_masking_format_id.setter
    def default_masking_format_id(self, default_masking_format_id):
        """
        Sets the default_masking_format_id of this SensitiveTypePattern.
        The OCID of the library masking format that should be used to mask the sensitive columns associated with the sensitive type.


        :param default_masking_format_id: The default_masking_format_id of this SensitiveTypePattern.
        :type: str
        """
        self._default_masking_format_id = default_masking_format_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SourceDetails(object):
    """
    Specify one of the following values depending for the 'type' attribute based on the application that you want to migrate.

    Specify `OCIC` if you want to migrate Oracle Java Cloud Service, Oracle Analytics Cloud - Classic, Oracle Integration, and Oracle
    SOA Cloud Service applications from Oracle Cloud Infrastructure - Classic.

    Specify `INTERNAL_COMPUTE` if you have a traditional Oracle Cloud Infrastructure - Classic account and you want to migrate Oracle
    Process Cloud Service or Oracle Integration Cloud Service applications.

    Specify `OCC` if you want to migrate applications from Oracle Cloud@Customer.
    """

    #: A constant which can be used with the type property of a SourceDetails.
    #: This constant has a value of "OCIC"
    TYPE_OCIC = "OCIC"

    #: A constant which can be used with the type property of a SourceDetails.
    #: This constant has a value of "INTERNAL_COMPUTE"
    TYPE_INTERNAL_COMPUTE = "INTERNAL_COMPUTE"

    #: A constant which can be used with the type property of a SourceDetails.
    #: This constant has a value of "OCC"
    TYPE_OCC = "OCC"

    #: A constant which can be used with the type property of a SourceDetails.
    #: This constant has a value of "OCIC_IDCS"
    TYPE_OCIC_IDCS = "OCIC_IDCS"

    #: A constant which can be used with the type property of a SourceDetails.
    #: This constant has a value of "IMPORT"
    TYPE_IMPORT = "IMPORT"

    def __init__(self, **kwargs):
        """
        Initializes a new SourceDetails object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.application_migration.models.ImportSourceDetails`
        * :class:`~oci.application_migration.models.OccSourceDetails`
        * :class:`~oci.application_migration.models.InternalSourceDetails`
        * :class:`~oci.application_migration.models.OcicSourceDetails`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this SourceDetails.
            Allowed values for this property are: "OCIC", "INTERNAL_COMPUTE", "OCC", "OCIC_IDCS", "IMPORT", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type type: str

        """
        self.swagger_types = {
            'type': 'str'
        }

        self.attribute_map = {
            'type': 'type'
        }

        self._type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['type']

        if type == 'IMPORT':
            return 'ImportSourceDetails'

        if type == 'OCC':
            return 'OccSourceDetails'

        if type == 'INTERNAL_COMPUTE':
            return 'InternalSourceDetails'

        if type == 'OCIC':
            return 'OcicSourceDetails'
        else:
            return 'SourceDetails'

    @property
    def type(self):
        """
        **[Required]** Gets the type of this SourceDetails.
        The type of source environment.

        Allowed values for this property are: "OCIC", "INTERNAL_COMPUTE", "OCC", "OCIC_IDCS", "IMPORT", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The type of this SourceDetails.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SourceDetails.
        The type of source environment.


        :param type: The type of this SourceDetails.
        :type: str
        """
        allowed_values = ["OCIC", "INTERNAL_COMPUTE", "OCC", "OCIC_IDCS", "IMPORT"]
        if not value_allowed_none_or_none_sentinel(type, allowed_values):
            type = 'UNKNOWN_ENUM_VALUE'
        self._type = type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
